const http = require('http');

// 测试登录API
function testLogin() {
  const postData = JSON.stringify({
    email: 'admin@example.com',
    password: 'admin123'
  });

  const options = {
    hostname: 'localhost',
    port: 3000,
    path: '/api/auth/admin-login',
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
      'Content-Length': Buffer.byteLength(postData)
    }
  };

  const req = http.request(options, (res) => {
    console.log(`状态码: ${res.statusCode}`);
    console.log(`响应头: ${JSON.stringify(res.headers)}`);
    
    let data = '';
    res.on('data', (chunk) => {
      data += chunk;
    });
    
    res.on('end', () => {
      console.log('响应体:', data);
      try {
        const parsedData = JSON.parse(data);
        console.log('解析后的响应:', JSON.stringify(parsedData, null, 2));
        
        if (parsedData.success) {
          console.log('✅ 登录测试成功！');
          console.log('用户信息:', parsedData.user);
          console.log('JWT令牌已生成');
        } else {
          console.log('❌ 登录测试失败:', parsedData.error);
        }
      } catch (error) {
        console.log('❌ 解析响应失败:', error.message);
      }
    });
  });

  req.on('error', (e) => {
    console.error(`请求错误: ${e.message}`);
  });

  req.write(postData);
  req.end();
}

// 等待服务器启动
console.log('等待服务器启动...');
setTimeout(() => {
  console.log('开始测试登录流程...');
  testLogin();
}, 3000); 